@@ -71,6 +71,8 @@ OC.L10N.register(
     "Transferred from %1$s on %2$s" : "於 %2$s 從 %1$s 轉移",
     "Files compatibility" : "檔案相容性",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允許限制檔案名稱以確保檔案可以與所有客戶端同步。預設情況下，允許 POSIX（例如 Linux 或 macOS）上所有有效的檔案名稱。",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用與 Windows 相容的檔案名稱後，無法再修改現有檔案，但可以由其擁有者重新命名為有效的新名稱。",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "啟用此設定後，也可以自動遷移檔案，詳情請參閱關於 occ 命令的文件。",
     "Enforce Windows compatibility" : "強制 Windows 相容性",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "這會封鎖在 Windows 系統上無效的檔案名稱，例如使用保留名稱或特殊字元。但這不會強制區分大小寫的相容性。",
     "File Management" : "檔案管理",
@@ -95,6 +97,7 @@ OC.L10N.register(
     "Invalid filename." : "無效的檔案名稱。",
     "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
     "Rename file" : "重新命名檔案",
+    "Folder" : "資料夾",
     "Pending" : "待處理",
     "Unknown date" : "未知日期",
     "Clear filter" : "清除過濾條件",
@@ -326,11 +329,9 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法取用，請檢查伺服器紀錄檔或聯絡管理員",
     "Storage is temporarily not available" : "儲存空間暫時無法使用",
     "Unexpected error: {error}" : "意外錯誤：{error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 個資料夾"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 個檔案"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
+    "_%n file_::_%n files_" : ["%n 個檔案"],
+    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
+    "_%n hidden_::_%n hidden_" : ["%n 個隱藏"],
     "Filename must not be empty." : "檔案名稱不能為空。",
     "\"{char}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{char}」",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "「{segment}」是保留名稱，不允許用在檔案名稱。",
@@ -404,8 +405,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "刪除「{fileName}」時發生錯誤。",
     "No search results in other folders for {tag}{filter}{endtag}" : "在其他資料夾中沒有找到 {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "請輸入兩個字元以上，以便在其他資料夾搜尋",
-    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
-    "_%n file_::_%n files_" : ["%n 個檔案"],
     "{dirs} and {files}" : "{dirs} 和 {files}",
     "_including %n hidden_::_including %n hidden_" : ["包含 %n 個隱藏檔"],
     "You do not have permission to upload or create files here" : "您無權在此上傳或建立檔案",
@@ -445,6 +444,11 @@ OC.L10N.register(
     "Edit file locally" : "本機編輯檔案",
     "Edit online" : "線上編輯",
     "Create new templates folder" : "建立新的範本資料夾",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 個資料夾"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 個檔案"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
     "List of favorites files and folders." : "喜愛檔案與資料夾的清單。",
     "Personal Files" : "個人檔案",
     "Text file" : "文字檔案",
